#!/bin/bash
#-------------------------------------------------------
# Purpose: This script will install the included version
#          of Kiwix to a RACHEL-Plus device to provide 
#          support for the included Kiwix content. It is 
#          run after the module has been downloaded. 
# Author:  James Kainer - james@worldpossible.org 
# Version: 3.1.2
#-------------------------------------------------------

MIN_VER="3.1.2"     
VER="3.1.2"
DIR="/var/kiwix"
MODDIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
FILES="${MODDIR}/data/kiwix/"

function log(){
  ERR=$1
  echo -e "RACHEL: $1"
}

function check(){
  if [ "${?}" -ne "0" ]; then
    echo "${ERR}"
    exit 1;
  fi
}

log "== Running Kiwix install script =="

if [ -e /var/www/modules ]; then
  log "Kiwix install support is only provided for RACHEL-Plus devices through this module."
  
  if [ -d $FILES ]; then
    log "Removing Kiwix install files"
    rm -rf $FILES; check
  fi

  exit 0
fi

upgrade=0

if [ -d "${DIR}" ]; then

  if [ -e /etc/kiwix-version ]; then
    log "Getting Kiwix version"
    ETC_VER=$(cat /etc/kiwix-version | cut -c1-5) 

    if [ "$ETC_VER" != "$VER" ]; then
       log "Upgrading Kiwix due to /etc version mismatch"
       upgrade=1
    fi
  else
    log "Upgrading Kiwix due to missing /etc version file"     
    upgrade=1
  fi        

  log "Getting version from kiwix-serve"
  KWX_VER=$(${DIR}/bin/kiwix-serve --version) 

  if [ $? -ne 0 ]; then
    log "Updating due to kiwix-serve version command failure"
    upgrade=1    
  else
      if [ "$KWX_VER" != "$VER" ]; then
        log "Upgrading due to version mismatch"
        upgrade=1
      fi       
  fi
else
  log "Upgrading due to missing Kiwix directory"
  upgrade=1
fi

if [ $upgrade = 0 ]; then
  log "No Kiwix upgrade required"

  if [ -d $FILES ]; then
    log "Removing Kiwix install files"
    sudo rm -rf $FILES; check
  fi
  
  log "==== Module install complete ===="
  exit 0 
fi  

if [ ! -d "${FILES}" ]; then
  log "Unable to locate kiwix install files"
  exit 1
fi
  
log "Stopping Kiwix service"
sudo systemctl stop kiwix; check

if [ -d "$DIR" ]; then
  log "Deleting the existing Kiwix directory"
  sudo rm -rf $DIR; check
fi

log "Creating the new Kiwix directory"
sudo mkdir -p "${DIR}"/bin; check

log "Installing sample zim file"
sudo cp "${FILES}"/empty.zim "${DIR}"/empty.zim; check

log "Installing Kiwix sample library"
sudo cp "${FILES}"/library.xml "${DIR}"/library.xml; check

log "Installing Kiwix start service script"
sudo cp "${FILES}"/rachelKiwixStart.sh "${DIR}"/rachelKiwixStart.sh; check

log "Installing Kiwix $VER bin files"
sudo cp "${FILES}"/bin/kiwix-read    "${DIR}"/bin/; check
sudo cp "${FILES}"/bin/kiwix-serve   "${DIR}"/bin/; check
sudo cp "${FILES}"/bin/kiwix-search  "${DIR}"/bin/; check
sudo cp "${FILES}"/bin/kiwix-manage  "${DIR}"/bin/; check

log "Setting permissions on Kiwix bin files"
sudo chmod 775 "${DIR}"/bin/*; check

if [ -e /etc/init.d/kiwix ]; then
  log "Deleting existing Kiwix service file"
  sudo rm /etc/init.d/kiwix; check
fi

log "Installing new Kiwix service file"
sudo cp "${FILES}"/kiwix /etc/init.d/kiwix; check

log "loading new Kiwix service file"
sudo systemctl daemon-reload; check

log "Setting permissions on Kiwix service file"
sudo chmod +x /etc/init.d/kiwix; check

log "Registering Kiwix service as default"
sudo update-rc.d kiwix defaults; check

if [ -e /etc/kiwix-version ]; then
  log "Deleting existing kiwix-version file"
  sudo rm /etc/kiwix-version; check
fi

log "Generating kiwix-version file"
sudo echo "${VER}" | sudo tee /etc/kiwix-version; check

log "Starting Kiwix service"
sudo systemctl start kiwix; check

log "Removing the package from the install dir"  MSG="Unable to delete the Kiwix package"
sudo rm -rf $FILES; check
  
log "Kiwix has been successfully upgraded to ${VER}"
log "== Finished running Kiwix install script =="
exit 0
